==> kadu_0.11.1.orig.tar.bz2: kadu-0.11.1/plugins/autoaway/translations/autoaway_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>@default</name>
    <message>
        <source>Status</source>
        <translation>Stav</translation>
    </message>
    <message>
        <source>Autoaway</source>
        <translation>Automatická nepřítomnost</translation>
    </message>
    <message>
        <source>Check idle every</source>
        <translation>Prověřit nečinnost každých</translation>
    </message>
    <message>
        <source>Enable autoaway</source>
        <translation>Povolit automatickou nepřítomnost</translation>
    </message>
    <message>
        <source>Set status to away after</source>
        <translation>Nastavit stav na &quot;nepřítomen&quot; po</translation>
    </message>
    <message>
        <source>Enable autoinvisible</source>
        <translation>Povolit automatickou neviditelnost</translation>
    </message>
    <message>
        <source>Set status to invisible after</source>
        <translation>Nastavit stav na &quot;neviditelný&quot; po</translation>
    </message>
    <message>
        <source>Enable autodisconnect</source>
        <translation>Povolit automatické odpojení</translation>
    </message>
    <message>
        <source>Disconnect after</source>
        <translation>Odpojit po</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Nahradit</translation>
    </message>
    <message>
        <source>New description</source>
        <translation>Nový popis</translation>
    </message>
    <message>
        <source>Parse AutoStatus</source>
        <translation>Zpracovat automatický stav</translation>
    </message>
    <message>
        <source>Enable auto extended away</source>
        <translation>Povolit automatickou rozšířenou nepřítomnost</translation>
    </message>
    <message>
        <source>Set status to extended away after</source>
        <translation>Nastavit stav na &quot;rozšířeně nepřítomen&quot; po</translation>
    </message>
    <message>
        <source>Auto refresh status</source>
        <translation>Obnovit automaticky stav</translation>
    </message>
    <message numerus="yes">
        <source>[every] %n second(s)</source>
        <translation>
            <numerusform>[každou] 1 sekundu</numerusform>
            <numerusform>[každé] %n sekundy</numerusform>
            <numerusform>[každých] %n sekund</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>[after] %n second(s)</source>
        <translation>
            <numerusform>[po] 1 sekundě</numerusform>
            <numerusform>[po] %n sekundách</numerusform>
            <numerusform>[po] %n sekundách</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation>
            <numerusform>%n sekunda</numerusform>
            <numerusform>%n sekundy</numerusform>
            <numerusform>%n sekund</numerusform>
        </translation>
    </message>
    <message>
        <source>Do Not Change</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add in the Front</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add at the Back</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AutoAway</name>
    <message>
        <source>Don&apos;t refresh</source>
        <translation>Neobnovovat</translation>
    </message>
</context>
</TS>

==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/autoaway/translations/autoaway_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Status</source>
        <translation>Stav</translation>
    </message>
    <message>
        <source>Autoaway</source>
        <translation>Automatická nepřítomnost</translation>
    </message>
    <message>
        <source>Check idle every</source>
        <translation>Prověřit nečinnost každých</translation>
    </message>
    <message>
        <source>Enable autoaway</source>
        <translation>Povolit automatickou nepřítomnost</translation>
    </message>
    <message>
        <source>Set status to away after</source>
        <translation>Nastavit stav na nepřítomen po</translation>
    </message>
    <message>
        <source>Enable autoinvisible</source>
        <translation>Povolit automatickou neviditelnost</translation>
    </message>
    <message>
        <source>Set status to invisible after</source>
        <translation>Nastavit stav na neviditelný po</translation>
    </message>
    <message>
        <source>Enable autodisconnect</source>
        <translation>Povolit automatické odpojení</translation>
    </message>
    <message>
        <source>Disconnect after</source>
        <translation>Odpojit po</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Nahradit</translation>
    </message>
    <message>
        <source>New description</source>
        <translation>Nový popis</translation>
    </message>
    <message>
        <source>Parse AutoStatus</source>
        <translation>Zpracovat automatický stav</translation>
    </message>
    <message>
        <source>Enable auto extended away</source>
        <translation>Povolit automatickou rozšířenou nepřítomnost</translation>
    </message>
    <message>
        <source>Set status to extended away after</source>
        <translation>Nastavit stav na rozšířeně nepřítomen po</translation>
    </message>
    <message>
        <source>Auto refresh status</source>
        <translation>Obnovit automaticky stav</translation>
    </message>
    <message numerus="yes">
        <source>[every] %n second(s)</source>
        <translation><numerusform>[každou] 1 sekundu</numerusform><numerusform>[každé] %n sekundy</numerusform><numerusform>[každých] %n sekund</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>[after] %n second(s)</source>
        <translation><numerusform>[po] 1 sekundě</numerusform><numerusform>[po] %n sekundách</numerusform><numerusform>[po] %n sekundách</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation><numerusform>%n sekunda</numerusform><numerusform>%n sekundy</numerusform><numerusform>%n sekund</numerusform></translation>
    </message>
    <message>
        <source>Do Not Change</source>
        <translation>Neměnit</translation>
    </message>
    <message>
        <source>Add in the Front</source>
        <translation>Přidat dopředu</translation>
    </message>
    <message>
        <source>Add at the Back</source>
        <translation>Přidat dozadu</translation>
    </message>
</context>
<context>
    <name>AutoAway</name>
    <message>
        <source>Don&apos;t refresh</source>
        <translation>Neobnovovat</translation>
    </message>
</context>
</TS>
